"""Script for running tsunami inundation scenario for Dampier, WA, Australia.

Source data such as elevation and boundary data is assumed to be available in
directories specified by project.py
The output sww file is stored in project.output_time_dir 

The scenario is defined by a triangular mesh created from project.polygon,
the elevation data and a simulated submarine landslide.

Ole Nielsen and Duncan Gray, GA - 2005 and Jane Sexton, Nick Bartzis, GA - 2006
"""

#------------------------------------------------------------------------------
# Import necessary modules
#------------------------------------------------------------------------------

# Standard modules
from os import sep
from os.path import dirname, basename
from os import mkdir, access, F_OK
from shutil import copy
import time
import sys

# Related major packages
from anuga.shallow_water import Domain
from anuga.shallow_water.data_manager import convert_dem_from_ascii2netcdf, dem2pts,start_screen_catcher, copy_code_files
from anuga.geospatial_data.geospatial_data import *
from anuga.shallow_water.data_manager import start_screen_catcher, copy_code_files

# Application specific imports
import project   # Definition of file names and polygons

#------------------------------------------------------------------------------
# Copy scripts to time stamped output directory and capture screen
# output to file
#------------------------------------------------------------------------------

copy_code_files(project.output_build_time_dir,__file__, 
               dirname(project.__file__)+sep+ project.__name__+'.py' )

start_screen_catcher(project.output_build_time_dir)

print 'USER: ', project.user, project.host

#-------------------------------------------------------------------------------
# Preparation of topographic data
#
# Convert ASC 2 DEM 2 PTS using source data and store result in source data
# Do for coarse and fine data
# Fine pts file to be clipped to area of interest
#-------------------------------------------------------------------------------

# topography directory filenames
onshore_in_dir_name = project.onshore_in_dir_name
coast_in_dir_name = project.coast_in_dir_name
island_in_dir_name = project.island_in_dir_name
offshore_in_dir_name = project.offshore_in_dir_name
offshore_in_dir_name1 = project.offshore_in_dir_name1
offshore_in_dir_name2 = project.offshore_in_dir_name2
offshore_in_dir_name3 = project.offshore_in_dir_name3

onshore_dir_name = project.onshore_dir_name
coast_dir_name = project.coast_dir_name
island_dir_name = project.island_dir_name
offshore_dir_name = project.offshore_dir_name
offshore_dir_name1 = project.offshore_dir_name1
offshore_dir_name2 = project.offshore_dir_name2
offshore_dir_name3 = project.offshore_dir_name3

# creates DEM from asc data
print "creates DEMs from ascii data"
convert_dem_from_ascii2netcdf(onshore_in_dir_name, basename_out=onshore_dir_name, use_cache=True, verbose=True)
convert_dem_from_ascii2netcdf(island_in_dir_name, basename_out=island_dir_name, use_cache=True, verbose=True)

#creates pts file for onshore DEM
dem2pts(onshore_dir_name, use_cache=True, verbose=True)

#creates pts file for island DEM
dem2pts(island_dir_name, use_cache=True, verbose=True)

print'create Geospatial data1 objects from topographies'
G1 = Geospatial_data(file_name = onshore_dir_name + '.pts',verbose=True)
G2 = Geospatial_data(file_name = coast_in_dir_name + '.txt',verbose=True)
G3 = Geospatial_data(file_name = island_dir_name + '.pts',verbose=True)
print'create Geospatial data1 objects from bathymetry'
G_off = Geospatial_data(file_name = offshore_in_dir_name + '.txt',verbose=True)
G_off1 = Geospatial_data(file_name = offshore_in_dir_name1 + '.txt',verbose=True)
G_off2 = Geospatial_data(file_name = offshore_in_dir_name2 + '.txt',verbose=True)
G_off3 = Geospatial_data(file_name = offshore_in_dir_name3 + '.txt',verbose=True)
print'finished reading in files'

print'add all geospatial objects'
G = G1 + G2 + G3 + G_off + G_off1 + G_off2 + G_off3

print'clip combined geospatial object by bounding polygon'
G_clip = G.clip(project.poly_all, verbose=False)

print'export combined DEM file'
if access(project.topographies_dir,F_OK) == 0:
    mkdir (project.topographies_dir)
G_clip.export_points_file(project.combined_dir_name + '.pts')

import sys
sys.exit()






